# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DayOfWeekSensor(BaseSensorOperator):
    week_day: "_empty"
    use_task_execution_day: "_empty"
