# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class HttpSensor(BaseSensorOperator):
    endpoint: "str"
    http_conn_id: "str"
    method: "str"
    request_params: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    headers: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    response_check: "typing.Union[typing.Callable[..., bool], NoneType]"
    extra_options: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
