# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.sql import (
    SQLCheckOperator,
    SQLIntervalCheckOperator,
    SQLThresholdCheckOperator,
    SQLValueCheckOperator,
)


class CheckOperator(SQLCheckOperator):
    pass


class IntervalCheckOperator(SQLIntervalCheckOperator):
    pass


class ThresholdCheckOperator(SQLThresholdCheckOperator):
    pass


class ValueCheckOperator(SQLValueCheckOperator):
    pass
