# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.gcs import (
    GCSListObjectsOperator,
)


class GoogleCloudStorageListOperator(GCSListObjectsOperator):
    pass
