# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DataflowCreateJavaJobOperator(BaseOperator):
    jar: "str"
    job_name: "str"
    dataflow_default_options: "typing.Union[dict, NoneType]"
    options: "typing.Union[dict, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    location: "str"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    poll_sleep: "int"
    job_class: "typing.Union[str, NoneType]"
    check_if_running: "CheckJobRunning"
    multiple_jobs: "typing.Union[bool, NoneType]"
    cancel_timeout: "typing.Union[int, NoneType]"
    wait_until_finished: "typing.Union[bool, NoneType]"


class DataflowCreatePythonJobOperator(BaseOperator):
    py_file: "str"
    job_name: "str"
    dataflow_default_options: "typing.Union[dict, NoneType]"
    options: "typing.Union[dict, NoneType]"
    py_interpreter: "str"
    py_options: "typing.Union[typing.List[str], NoneType]"
    py_requirements: "typing.Union[typing.List[str], NoneType]"
    py_system_site_packages: "bool"
    project_id: "typing.Union[str, NoneType]"
    location: "str"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    poll_sleep: "int"
    drain_pipeline: "bool"
    cancel_timeout: "typing.Union[int, NoneType]"
    wait_until_finished: "typing.Union[bool, NoneType]"


class DataflowTemplatedJobStartOperator(BaseOperator):
    template: "str"
    job_name: "str"
    options: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    dataflow_default_options: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    parameters: "typing.Union[typing.Dict[str, str], NoneType]"
    project_id: "typing.Union[str, NoneType]"
    location: "str"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    poll_sleep: "int"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    environment: "typing.Union[typing.Dict, NoneType]"
    cancel_timeout: "typing.Union[int, NoneType]"
    wait_until_finished: "typing.Union[bool, NoneType]"
