# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AWSAthenaOperator(BaseOperator):
    query: "str"
    database: "str"
    output_location: "str"
    aws_conn_id: "str"
    client_request_token: "typing.Union[str, NoneType]"
    workgroup: "str"
    query_execution_context: "typing.Union[typing.Dict[str, str], NoneType]"
    result_configuration: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    sleep_time: "int"
    max_tries: "typing.Union[int, NoneType]"
