# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.local_to_gcs import (
    LocalFilesystemToGCSOperator,
)


class FileToGoogleCloudStorageOperator(LocalFilesystemToGCSOperator):
    pass
