# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.transfers.redshift_to_s3 import (
    RedshiftToS3Operator,
)


class RedshiftToS3Transfer(RedshiftToS3Operator):
    pass
