# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureContainerInstancesOperator(BaseOperator):
    ci_conn_id: "str"
    registry_conn_id: "typing.Union[str, NoneType]"
    resource_group: "str"
    name: "str"
    image: "str"
    region: "str"
    environment_variables: "typing.Union[dict, NoneType]"
    secured_variables: "typing.Union[str, NoneType]"
    volumes: "typing.Union[list, NoneType]"
    memory_in_gb: "typing.Union[typing.Any, NoneType]"
    cpu: "typing.Union[typing.Any, NoneType]"
    gpu: "typing.Union[typing.Any, NoneType]"
    command: "typing.Union[typing.List[str], NoneType]"
    remove_on_error: "bool"
    fail_if_exists: "bool"
    tags: "typing.Union[typing.Dict[str, str], NoneType]"
    os_type: "str"
    restart_policy: "str"
    ip_address: "typing.Union[azure.mgmt.containerinstance.models.ip_address_py3.IpAddress, NoneType]"
    ports: "typing.Union[typing.List[azure.mgmt.containerinstance.models.container_port_py3.ContainerPort], NoneType]"
