# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.docker.operators.docker import DockerOperator


class DockerSwarmOperator(DockerOperator):
    image: "str"
    enable_logging: "bool"
