# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class PapermillOperator(BaseOperator):
    input_nb: "typing.Union[str, NoneType]"
    output_nb: "typing.Union[str, NoneType]"
    parameters: "typing.Union[typing.Dict, NoneType]"
