# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.dataflow import (
    DataflowCreateJavaJobOperator,
    DataflowCreatePythonJobOperator,
    DataflowTemplatedJobStartOperator,
)


class DataFlowJavaOperator(DataflowCreateJavaJobOperator):
    pass


class DataFlowPythonOperator(DataflowCreatePythonJobOperator):
    pass


class DataflowTemplateOperator(DataflowTemplatedJobStartOperator):
    pass
