# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.transfers.gcs_to_s3 import (
    GCSToS3Operator,
)


class GoogleCloudStorageToS3Operator(GCSToS3Operator):
    pass
