# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.speech_to_text import (
    CloudSpeechToTextRecognizeSpeechOperator,
)


class GcpSpeechToTextRecognizeSpeechOperator(CloudSpeechToTextRecognizeSpeechOperator):
    pass
