# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class ImapAttachmentSensor(BaseSensorOperator):
    attachment_name: "_empty"
    check_regex: "_empty"
    mail_folder: "_empty"
    mail_filter: "_empty"
    conn_id: "_empty"
