# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SnsPublishOperator(BaseOperator):
    target_arn: "str"
    message: "str"
    aws_conn_id: "str"
    subject: "typing.Union[str, NoneType]"
    message_attributes: "typing.Union[dict, NoneType]"
