# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudTranslateTextOperator(BaseOperator):
    values: "typing.Union[typing.List[str], str]"
    target_language: "str"
    format_: "str"
    source_language: "typing.Union[str, NoneType]"
    model: "str"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
