# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SSHOperator(BaseOperator):
    ssh_hook: "typing.Union[airflow.providers.ssh.hooks.ssh.SSHHook, NoneType]"
    ssh_conn_id: "typing.Union[str, NoneType]"
    remote_host: "typing.Union[str, NoneType]"
    command: "typing.Union[str, NoneType]"
    timeout: "int"
    environment: "typing.Union[dict, NoneType]"
    get_pty: "bool"
