# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.dummy import DummyOperator
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class ExternalTaskMarker(DummyOperator):
    external_dag_id: "str"
    external_task_id: "str"
    execution_date: "typing.Union[str, datetime.datetime, NoneType]"
    recursion_depth: "int"


class ExternalTaskSensor(BaseSensorOperator):
    external_dag_id: "str"
    external_task_id: "typing.Union[str, NoneType]"
    allowed_states: "typing.Union[typing.Iterable[str], NoneType]"
    failed_states: "typing.Union[typing.Iterable[str], NoneType]"
    execution_delta: "typing.Union[datetime.timedelta, NoneType]"
    execution_date_fn: "typing.Union[typing.Callable, NoneType]"
    check_existence: "bool"
