# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.oracle.transfers.oracle_to_oracle import (
    OracleToOracleOperator,
)


class OracleToOracleTransfer(OracleToOracleOperator):
    pass
