# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3DeleteObjectsOperator(BaseOperator):
    bucket: "str"
    keys: "typing.Union[str, list, NoneType]"
    prefix: "typing.Union[str, NoneType]"
    aws_conn_id: "str"
    verify: "typing.Union[str, bool, NoneType]"
