# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3CopyObjectOperator(BaseOperator):
    source_bucket_key: "str"
    dest_bucket_key: "str"
    source_bucket_name: "typing.Union[str, NoneType]"
    dest_bucket_name: "typing.Union[str, NoneType]"
    source_version_id: "typing.Union[str, NoneType]"
    aws_conn_id: "str"
    verify: "typing.Union[str, bool, NoneType]"
    acl_policy: "typing.Union[str, NoneType]"
