# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSBucketCreateAclEntryOperator(BaseOperator):
    bucket: "str"
    entity: "str"
    role: "str"
    user_project: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSObjectCreateAclEntryOperator(BaseOperator):
    bucket: "str"
    object_name: "str"
    entity: "str"
    role: "str"
    generation: "typing.Union[int, NoneType]"
    user_project: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSDeleteObjectsOperator(BaseOperator):
    bucket_name: "str"
    objects: "typing.Union[typing.Iterable[str], NoneType]"
    prefix: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSListObjectsOperator(BaseOperator):
    bucket: "str"
    prefix: "typing.Union[str, NoneType]"
    delimiter: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSCreateBucketOperator(BaseOperator):
    bucket_name: "str"
    resource: "typing.Union[typing.Dict, NoneType]"
    storage_class: "str"
    location: "str"
    project_id: "typing.Union[str, NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
