# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.s3_list import S3ListOperator


class S3ToGCSOperator(S3ListOperator):
    bucket: "_empty"
    prefix: "_empty"
    delimiter: "_empty"
    aws_conn_id: "_empty"
    verify: "_empty"
    gcp_conn_id: "_empty"
    dest_gcs_conn_id: "_empty"
    dest_gcs: "_empty"
    delegate_to: "_empty"
    replace: "_empty"
    gzip: "_empty"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
