# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BashOperator(BaseOperator):
    bash_command: "str"
    env: "typing.Union[typing.Dict[str, str], NoneType]"
    output_encoding: "str"
    skip_exit_code: "int"
