# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class PostgresOperator(BaseOperator):
    sql: "str"
    postgres_conn_id: "str"
    autocommit: "bool"
    parameters: "typing.Union[typing.Mapping, typing.Iterable, NoneType]"
    database: "typing.Union[str, NoneType]"
