# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BaseSerialization:
    pass


class SerializedBaseOperator(BaseOperator, BaseSerialization):
    pass
