# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3FileTransformOperator(BaseOperator):
    source_s3_key: "str"
    dest_s3_key: "str"
    transform_script: "typing.Union[str, NoneType]"
    select_expression: "_empty"
    script_args: "typing.Union[typing.Sequence[str], NoneType]"
    source_aws_conn_id: "str"
    source_verify: "typing.Union[bool, str, NoneType]"
    dest_aws_conn_id: "str"
    dest_verify: "typing.Union[bool, str, NoneType]"
    replace: "bool"
