# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.gcs_to_local import (
    GCSToLocalFilesystemOperator,
)


class GoogleCloudStorageDownloadOperator(GCSToLocalFilesystemOperator):
    pass
