# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.models.skipmixin import SkipMixin


class SmartSensorOperator(BaseOperator, SkipMixin):
    poke_interval: "_empty"
    smart_sensor_timeout: "_empty"
    soft_fail: "_empty"
    shard_min: "_empty"
    shard_max: "_empty"
    poke_timeout: "_empty"
