# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class EmrTerminateJobFlowOperator(BaseOperator):
    job_flow_id: "str"
    aws_conn_id: "str"
