# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.bigquery_to_gcs import (
    BigQueryToGCSOperator,
)


class BigQueryToCloudStorageOperator(BigQueryToGCSOperator):
    pass
