# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AwsBatchOperator(BaseOperator):
    job_name: "str"
    job_definition: "str"
    job_queue: "str"
    overrides: "dict"
    array_properties: "typing.Union[dict, NoneType]"
    parameters: "typing.Union[dict, NoneType]"
    job_id: "typing.Union[str, NoneType]"
    waiters: "typing.Union[typing.Any, NoneType]"
    max_retries: "typing.Union[int, NoneType]"
    status_retries: "typing.Union[int, NoneType]"
    aws_conn_id: "typing.Union[str, NoneType]"
    region_name: "typing.Union[str, NoneType]"
    tags: "typing.Union[dict, NoneType]"
