# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.translate_speech import (
    CloudTranslateSpeechOperator,
)


class GcpTranslateSpeechOperator(CloudTranslateSpeechOperator):
    pass
