# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class BashSensor(BaseSensorOperator):
    bash_command: "_empty"
    env: "_empty"
    output_encoding: "_empty"
