# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.hive.transfers.mssql_to_hive import (
    MsSqlToHiveOperator,
)


class MsSqlToHiveTransfer(MsSqlToHiveOperator):
    pass
