# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.sql import SQLCheckOperator, SQLValueCheckOperator
from airfly._vendor.airflow.providers.qubole.operators.qubole import QuboleOperator


class _QuboleCheckOperatorMixin:
    pass


class QuboleCheckOperator(_QuboleCheckOperatorMixin, SQLCheckOperator, QuboleOperator):
    qubole_conn_id: "str"
    results_parser_callable: "typing.Callable"


class QuboleValueCheckOperator(
    _QuboleCheckOperatorMixin, SQLValueCheckOperator, QuboleOperator
):
    pass_value: "typing.Union[str, int, float]"
    tolerance: "typing.Union[int, float, NoneType]"
    results_parser_callable: "typing.Callable"
    qubole_conn_id: "str"
