# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.sql import (
    SQLCheckOperator,
    SQLIntervalCheckOperator,
    SQLValueCheckOperator,
)


class PrestoCheckOperator(SQLCheckOperator):
    pass


class PrestoIntervalCheckOperator(SQLIntervalCheckOperator):
    pass


class PrestoValueCheckOperator(SQLValueCheckOperator):
    pass
