# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_sql import (
    CloudSQLBaseOperator,
    CloudSQLCreateInstanceDatabaseOperator,
    CloudSQLCreateInstanceOperator,
    CloudSQLDeleteInstanceDatabaseOperator,
    CloudSQLDeleteInstanceOperator,
    CloudSQLExecuteQueryOperator,
    CloudSQLExportInstanceOperator,
    CloudSQLImportInstanceOperator,
    CloudSQLInstancePatchOperator,
    CloudSQLPatchInstanceDatabaseOperator,
)


class CloudSqlBaseOperator(CloudSQLBaseOperator):
    pass


class CloudSqlInstanceCreateOperator(CloudSQLCreateInstanceOperator):
    pass


class CloudSqlInstanceDatabaseCreateOperator(CloudSQLCreateInstanceDatabaseOperator):
    pass


class CloudSqlInstanceDatabaseDeleteOperator(CloudSQLDeleteInstanceDatabaseOperator):
    pass


class CloudSqlInstanceDatabasePatchOperator(CloudSQLPatchInstanceDatabaseOperator):
    pass


class CloudSqlInstanceDeleteOperator(CloudSQLDeleteInstanceOperator):
    pass


class CloudSqlInstanceExportOperator(CloudSQLExportInstanceOperator):
    pass


class CloudSqlInstanceImportOperator(CloudSQLImportInstanceOperator):
    pass


class CloudSqlInstancePatchOperator(CloudSQLInstancePatchOperator):
    pass


class CloudSqlQueryOperator(CloudSQLExecuteQueryOperator):
    pass
