# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BaseSQLToGCSOperator(BaseOperator):
    sql: "str"
    bucket: "str"
    filename: "str"
    schema_filename: "typing.Union[str, NoneType]"
    approx_max_file_size_bytes: "int"
    export_format: "str"
    field_delimiter: "str"
    null_marker: "typing.Union[str, NoneType]"
    gzip: "bool"
    schema: "typing.Union[str, list, NoneType]"
    parameters: "typing.Union[dict, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
