# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.datastore import (
    CloudDatastoreImportEntitiesOperator,
)


class DatastoreImportOperator(CloudDatastoreImportEntitiesOperator):
    pass
