# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.adls_to_gcs import (
    ADLSToGCSOperator,
)


class AdlsToGoogleCloudStorageOperator(ADLSToGCSOperator):
    pass
