# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.gcs_to_bigquery import (
    GCSToBigQueryOperator,
)


class GoogleCloudStorageToBigQueryOperator(GCSToBigQueryOperator):
    pass
