# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_storage_transfer_service import (
    CloudDataTransferServiceCancelOperationOperator,
    CloudDataTransferServiceCreateJobOperator,
    CloudDataTransferServiceDeleteJobOperator,
    CloudDataTransferServiceGCSToGCSOperator,
    CloudDataTransferServiceGetOperationOperator,
    CloudDataTransferServiceListOperationsOperator,
    CloudDataTransferServicePauseOperationOperator,
    CloudDataTransferServiceResumeOperationOperator,
    CloudDataTransferServiceS3ToGCSOperator,
    CloudDataTransferServiceUpdateJobOperator,
)


class GcpTransferServiceJobCreateOperator(CloudDataTransferServiceCreateJobOperator):
    pass


class GcpTransferServiceJobDeleteOperator(CloudDataTransferServiceDeleteJobOperator):
    pass


class GcpTransferServiceJobUpdateOperator(CloudDataTransferServiceUpdateJobOperator):
    pass


class GcpTransferServiceOperationCancelOperator(
    CloudDataTransferServiceCancelOperationOperator
):
    pass


class GcpTransferServiceOperationGetOperator(
    CloudDataTransferServiceGetOperationOperator
):
    pass


class GcpTransferServiceOperationPauseOperator(
    CloudDataTransferServicePauseOperationOperator
):
    pass


class GcpTransferServiceOperationResumeOperator(
    CloudDataTransferServiceResumeOperationOperator
):
    pass


class GcpTransferServiceOperationsListOperator(
    CloudDataTransferServiceListOperationsOperator
):
    pass


class GoogleCloudStorageToGoogleCloudStorageTransferOperator(
    CloudDataTransferServiceGCSToGCSOperator
):
    pass


class S3ToGoogleCloudStorageTransferOperator(CloudDataTransferServiceS3ToGCSOperator):
    pass
