# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.branch import BaseBranchOperator


class LatestOnlyOperator(BaseBranchOperator):
    task_id: "str"
    owner: "str"
    email: "typing.Union[str, typing.Iterable[str], NoneType]"
    email_on_retry: "bool"
    email_on_failure: "bool"
    retries: "typing.Union[int, NoneType]"
    retry_delay: "timedelta"
    retry_exponential_backoff: "bool"
    max_retry_delay: "typing.Union[datetime.timedelta, NoneType]"
    start_date: "typing.Union[datetime.datetime, NoneType]"
    end_date: "typing.Union[datetime.datetime, NoneType]"
    depends_on_past: "bool"
    wait_for_downstream: "bool"
    dag: "_empty"
    params: "typing.Union[typing.Dict, NoneType]"
    default_args: "typing.Union[typing.Dict, NoneType]"
    priority_weight: "int"
    weight_rule: "str"
    queue: "str"
    pool: "typing.Union[str, NoneType]"
    pool_slots: "int"
    sla: "typing.Union[datetime.timedelta, NoneType]"
    execution_timeout: "typing.Union[datetime.timedelta, NoneType]"
    on_execute_callback: "typing.Union[typing.Callable[[typing.Dict[str, typing.Any]], NoneType], NoneType]"
    on_failure_callback: "typing.Union[typing.Callable[[typing.Dict[str, typing.Any]], NoneType], NoneType]"
    on_success_callback: "typing.Union[typing.Callable[[typing.Dict[str, typing.Any]], NoneType], NoneType]"
    on_retry_callback: "typing.Union[typing.Callable[[typing.Dict[str, typing.Any]], NoneType], NoneType]"
    trigger_rule: "str"
    resources: "typing.Union[typing.Dict, NoneType]"
    run_as_user: "typing.Union[str, NoneType]"
    task_concurrency: "typing.Union[int, NoneType]"
    executor_config: "typing.Union[typing.Dict, NoneType]"
    do_xcom_push: "bool"
    inlets: "typing.Union[typing.Any, NoneType]"
    outlets: "typing.Union[typing.Any, NoneType]"
    task_group: "typing.Union[ForwardRef('TaskGroup'), NoneType]"
    doc: "typing.Union[str, NoneType]"
    doc_md: "typing.Union[str, NoneType]"
    doc_json: "typing.Union[str, NoneType]"
    doc_yaml: "typing.Union[str, NoneType]"
    doc_rst: "typing.Union[str, NoneType]"
