# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.mysql.transfers.vertica_to_mysql import (
    VerticaToMySqlOperator,
)


class VerticaToMySqlTransfer(VerticaToMySqlOperator):
    pass
