# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.hive.transfers.mysql_to_hive import (
    MySqlToHiveOperator,
)


class MySqlToHiveTransfer(MySqlToHiveOperator):
    pass
