# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToRedshiftOperator(BaseOperator):
    schema: "str"
    table: "str"
    s3_bucket: "str"
    s3_key: "str"
    redshift_conn_id: "str"
    aws_conn_id: "str"
    verify: "typing.Union[bool, str, NoneType]"
    column_list: "typing.Union[typing.List[str], NoneType]"
    copy_options: "typing.Union[typing.List, NoneType]"
    autocommit: "bool"
    truncate_table: "bool"
