# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.http.operators.http import SimpleHttpOperator


class DiscordWebhookOperator(SimpleHttpOperator):
    http_conn_id: "typing.Union[str, NoneType]"
    webhook_endpoint: "typing.Union[str, NoneType]"
    message: "str"
    username: "typing.Union[str, NoneType]"
    avatar_url: "typing.Union[str, NoneType]"
    tts: "bool"
    proxy: "typing.Union[str, NoneType]"
