# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.kubernetes_engine import (
    GKECreateClusterOperator,
    GKEDeleteClusterOperator,
    GKEStartPodOperator,
)


class GKEClusterCreateOperator(GKECreateClusterOperator):
    pass


class GKEClusterDeleteOperator(GKEDeleteClusterOperator):
    pass


class GKEPodOperator(GKEStartPodOperator):
    pass
